@@ -24,6 +24,7 @@
 #include <unistd.h>
 
 #include "xchat.h"
+#include <glib/ghash.h>
 
 #include "cfgfiles.h"
 #include "fe.h"
@@ -118,6 +119,9 @@ static const struct defaultserver def[] =
 	{0,			"irc.azzurra.org"},
 	{0,			"crypto.azzurra.org"},
 
+	{"Beirut", 0},
+	{0,			"irc.beirut.com"},
+
 	{"Buzzpot", 0},
 	{0,			"irc.chatspike.net"},
 
@@ -231,6 +235,9 @@ static const struct defaultserver def[] =
 	{"Hashmark",	0},
 	{0,			"irc.hashmark.net"},
 
+	{"IdleMonkeys", 0},
+	{0,			"irc.idlemonkeys.net"},
+
 	{"Infinity-IRC",	0},
 	{0,			"Atlanta.GA.US.Infinity-IRC.Org"},
 	{0,			"Babylon.NY.US.Infinity-IRC.Org"},
@@ -434,9 +441,6 @@ static const struct defaultserver def[] =
 	{"TNI3",			0},
 	{0,			"irc.tni3.com"},
 
-	{"TopGamers",	0},
-	{0,			"irc.topgamers.net"},
-
 	{"UnderNet",	0},
 	{0,			"us.undernet.org"},
 	{0,			"eu.undernet.org"},
@@ -449,6 +453,9 @@ static const struct defaultserver def[] =
 	{0,			"irc.telecoms.bg"},
 	{0,			"irc.tu-varna.edu"},
 
+	{"Whiffle",	0},
+	{0,			"irc.whiffle.org"},
+
 	{"Worldnet",		0},
 	{0,			"irc.worldnet.net"},
 	{0,			"irc.fr.worldnet.net"},
@@ -475,7 +482,7 @@ GSList *network_list = 0;
 
 
 void
-servlist_connect (session *sess, ircnet *net)
+servlist_connect (session *sess, ircnet *net, gboolean join)
 {
 	ircserver *ircserv;
 	GSList *list;
@@ -496,12 +503,16 @@ servlist_connect (session *sess, ircnet *net)
 	/* incase a protocol switch is added to the servlist gui */
 	server_fill_her_up (sess->server);
 
-	sess->willjoinchannel[0] = 0;
-	serv->password[0] = 0;
+	if (join)
+	{
+		sess->willjoinchannel[0] = 0;
 
-	if (net->autojoin)
-		safe_strcpy (sess->willjoinchannel, net->autojoin,
-						 sizeof (sess->willjoinchannel));
+		if (net->autojoin)
+			safe_strcpy (sess->willjoinchannel, net->autojoin,
+							 sizeof (sess->willjoinchannel));
+	}
+
+	serv->password[0] = 0;
 	if (net->pass)
 		safe_strcpy (serv->password, net->pass, sizeof (serv->password));
 
@@ -549,7 +560,7 @@ servlist_connect (session *sess, ircnet *net)
 }
 
 int
-servlist_connect_by_netname (session *sess, char *network)
+servlist_connect_by_netname (session *sess, char *network, gboolean join)
 {
 	ircnet *net;
 	GSList *list = network_list;
@@ -560,7 +571,7 @@ servlist_connect_by_netname (session *sess, char *network)
 
 		if (strcasecmp (net->name, network) == 0)
 		{
-			servlist_connect (sess, net);
+			servlist_connect (sess, net, join);
 			return 1;
 		}
 
@@ -603,7 +614,7 @@ servlist_auto_connect (session *sess)
 
 		if (net->flags & FLAG_AUTO_CONNECT)
 		{
-			servlist_connect (sess, net);
+			servlist_connect (sess, net, TRUE);
 			ret = 1;
 		}
 
@@ -618,7 +629,7 @@ servlist_cycle_cb (server *serv)
 {
 	PrintTextf (serv->server_session,
 		_("Cycling to next server in %s...\n"), ((ircnet *)serv->network)->name);
-	servlist_connect (serv->server_session, serv->network);
+	servlist_connect (serv->server_session, serv->network, TRUE);
 
 	return 0;
 }
@@ -650,7 +661,7 @@ servlist_cycle (server *serv)
 			if (del)
 				serv->recondelay_tag = fe_timeout_add (del, servlist_cycle_cb, serv);
 			else
-				servlist_connect (serv->server_session, net);
+				servlist_connect (serv->server_session, net, TRUE);
 
 			return TRUE;
 		}
@@ -682,8 +693,38 @@ servlist_server_find (ircnet *net, char *name, int *pos)
 	return NULL;
 }
 
+/* find a network (e.g. (ircnet *) to "FreeNode") from a hostname
+   (e.g. "irc.eu.freenode.net") */
+
 ircnet *
-servlist_net_find (char *name, int *pos)
+servlist_net_find_from_server (char *server_name)
+{
+	GSList *list = network_list;
+	GSList *slist;
+	ircnet *net;
+	ircserver *serv;
+
+	while (list)
+	{
+		net = list->data;
+
+		slist = net->servlist;
+		while (slist)
+		{
+			serv = slist->data;
+			if (strcasecmp (serv->hostname, server_name) == 0)
+				return net;
+			slist = slist->next;
+		}
+
+		list = list->next;
+	}
+
+	return NULL;
+}
+
+ircnet *
+servlist_net_find (char *name, int *pos, int (*cmpfunc) (const char *, const char *))
 {
 	GSList *list = network_list;
 	ircnet *net;
@@ -692,7 +733,7 @@ servlist_net_find (char *name, int *pos)
 	while (list)
 	{
 		net = list->data;
-		if (strcmp (net->name, name) == 0)
+		if (cmpfunc (net->name, name) == 0)
 		{
 			if (pos)
 				*pos = i;
@@ -824,7 +865,7 @@ servlist_load_defaults (void)
 				free (net->encoding);
 				net->encoding = strdup (def[i].charset);
 			}
-			if (!strcmp (def[i].network, "ChatJunkies"))
+			if (g_str_hash (def[i].network) == 0x8e1b96f7)
 				prefs.slist_select = j;
 			j++;
 		} else
