@@ -1,7 +1,7 @@
 /*
  * about.c - utilities for displaying and hiding the about dialog
  *
- * Copyright (C) 2004-2005 xchat-gnome team
+ * Copyright (C) 2004-2006 xchat-gnome team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -36,18 +36,18 @@ initialize_about_dialog (void)
 
 	const gchar *authors[] =
 	{
+		"Xavier Claessens <xclaesse@gmail.com>",
 		"Andre Dahlqvist",
-		"Guillaume Desmottes",
-		"Dan Kuester",
+		"Guillaume Desmottes <cass@skynet.be>",
+		"Dan Kuester <Daniel.Kuester@colorado.edu>",
 		"Bastien Nocera",
 		"Brian Pepple",
 		"Isak Savo",
-		"Evan Sheehan",
+		"Evan Sheehan <Wallace.Sheehan@gmail.com>",
 		"Rouslan Solomakhin",
 		"David Trowbridge <trowbrds@gmail.com>",
 		"Ramón Rey Vicente",
 		"Luis Villa",
-		"Claessens Xavier",
 		"Peter Železný",
 		NULL
 	};
@@ -88,7 +88,7 @@ initialize_about_dialog (void)
 	g_object_set (G_OBJECT (gui.about),
 		      "name",        "XChat-GNOME",
 		      "version",     VERSION,
-		      "copyright",   _("Copyright © 2004-2005"),
+		      "copyright",   _("Copyright © 2004-2006"),
 		      "comments",    _("It has been well observed that a trombone is not a suitable instrument for a gentleman"),
 		      "license",     license_trans,
 		      "website",     "http://xchat-gnome.navi.cx",
