@@ -1,7 +1,7 @@
 /*
  * channel-list.c - channel list
  *
- * Copyright (C) 2004-2005 xchat-gnome team
+ * Copyright (C) 2004-2006 xchat-gnome team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -34,38 +34,28 @@ static GSList *chanlists = NULL;
 static gboolean
 chanlist_filter (GtkTreeModel *model, GtkTreeIter *iter, channel_list_window *window)
 {
-	char *name, *topic, *found_topic = NULL, *found_name = NULL;
+	char *name, *topic;
 	int users;
 
-	/* FIXME */
-	return TRUE;
-
 	gtk_tree_model_get (model, iter, 0, &name, 2, &topic, 4, &users, -1);
 
-	if (window->filter_name && name == NULL)
-		return TRUE;
-	if (window->filter_topic && topic == NULL)
-		return TRUE;
-
 	/* filter number of users first, since it's fast */
 	if (users < window->minimum)
 		return FALSE;
 	if (window->maximum > 0 && users > window->maximum)
 		return FALSE;
 
-	if (!(window->filter_topic || window->filter_name))
-		return FALSE;
+	/* text filtering */
+	if (window->filter_topic && window->text_filter != NULL && strlen (window->text_filter) != 0)
+		/* We have something to filtre */
+		if (strcasestr (topic, window->text_filter) == NULL)
+			return FALSE;
 
-	if ((window->text_filter == NULL) || (strlen (window->text_filter) == 0))
-		return FALSE;
+	if (window->filter_name && window->text_filter != NULL && strlen (window->text_filter) != 0)
+		if (strcasestr (name, window->text_filter) == NULL)
+			return FALSE;
 
-	if (window->filter_topic)
-		found_topic = strcasestr (topic, window->text_filter);
-
-	if (window->filter_name)
-		found_name = strcasestr (name, window->text_filter);
-
-	return (found_name || found_topic);
+	return TRUE;
 }
 
 static gint
@@ -156,17 +146,15 @@ chanlist_save (GtkWidget *button, channel_list_window *win)
 }
 
 static void
-chanlist_join (GtkWidget *button, channel_list_window *win)
+join_selected_channel (GtkTreeView *treeview)
 {
-	GtkWidget *treeview;
 	GtkTreeModel *model;
 	GtkTreeSelection *select;
 	GtkTreeIter iter;
 	char *channel;
 	server *serv;
 
-	treeview = glade_xml_get_widget (win->xml, "channel list");
-	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (treeview));
+	select = gtk_tree_view_get_selection (treeview);
 	if (gtk_tree_selection_get_selected (select, &model, &iter))
 	{
 		gtk_tree_model_get (model, &iter, 0, &channel, 3, &serv, -1);
@@ -174,6 +162,15 @@ chanlist_join (GtkWidget *button, channel_list_window *win)
 	}
 }
 
+static void
+chanlist_join (GtkWidget *button, channel_list_window *win)
+{
+	GtkWidget *treeview;
+
+	treeview = glade_xml_get_widget (win->xml, "channel list");
+	join_selected_channel (GTK_TREE_VIEW (treeview));
+}
+
 static void
 chanlist_selected (GtkTreeSelection *selection, channel_list_window *win)
 {
@@ -195,6 +192,12 @@ chanlist_resize (GtkWidget *widget, GdkEventConfigure *event, gpointer data)
 	return FALSE;
 }
 
+static void
+row_activated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *column, channel_list_window *win)
+{
+	join_selected_channel (treeview);
+}
+
 static void
 minusers_changed (GtkSpinButton *button, channel_list_window *win)
 {
@@ -236,7 +239,7 @@ void
 create_channel_list (session *sess)
 {
 	channel_list_window *win;
-	GtkWidget *treeview, *widget;
+	GtkWidget *treeview, *widget, *refresh_button;
 	GtkCellRenderer *channel_r, *users_r, *topic_r;
 	GtkTreeViewColumn *channel_c, *users_c, *topic_c;
 	GtkSizeGroup *group;
@@ -286,18 +289,19 @@ create_channel_list (session *sess)
 	treeview = glade_xml_get_widget (win->xml, "channel list");
 	gtk_tree_view_set_search_column (GTK_TREE_VIEW (treeview), 1);
 
-	widget = glade_xml_get_widget (win->xml, "refresh button");
-	g_signal_connect (G_OBJECT (widget), "clicked", G_CALLBACK (chanlist_refresh), win);
+	refresh_button = glade_xml_get_widget (win->xml, "refresh button");
+	g_signal_connect (G_OBJECT (refresh_button), "clicked", G_CALLBACK (chanlist_refresh), win);
 	widget = glade_xml_get_widget (win->xml, "save button");
 	g_signal_connect (G_OBJECT (widget), "clicked", G_CALLBACK (chanlist_save), win);
 	widget = glade_xml_get_widget (win->xml, "join button");
 	gtk_widget_set_sensitive (widget, FALSE);
 	g_signal_connect (G_OBJECT (widget), "clicked", G_CALLBACK (chanlist_join), win);
+	g_signal_connect (G_OBJECT (treeview), "row-activated", G_CALLBACK (row_activated), win);
 
 	/*                                  channel name,  n-users,       topic,         server,         users */
 	win->store = gtk_list_store_new (5, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_POINTER, G_TYPE_INT);
 	win->filter = gtk_tree_model_filter_new (GTK_TREE_MODEL (win->store), NULL);
-	/* gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER (win->filter), (GtkTreeModelFilterVisibleFunc) chanlist_filter, win, NULL); */
+	 gtk_tree_model_filter_set_visible_func (GTK_TREE_MODEL_FILTER (win->filter), (GtkTreeModelFilterVisibleFunc) chanlist_filter, win, NULL);
 	win->sort = GTK_TREE_MODEL_SORT (gtk_tree_model_sort_new_with_model (GTK_TREE_MODEL (win->filter)));
 	gtk_tree_view_set_model (GTK_TREE_VIEW (treeview), GTK_TREE_MODEL (win->sort));
 	gtk_tree_view_set_headers_clickable (GTK_TREE_VIEW (treeview), TRUE);
@@ -351,8 +355,10 @@ create_channel_list (session *sess)
 	widget = glade_xml_get_widget (win->xml, "text filter");
 	g_signal_connect (G_OBJECT (widget), "changed", G_CALLBACK (filter_changed), win);
 	widget = glade_xml_get_widget (win->xml, "apply to topic");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), win->filter_topic);
 	g_signal_connect (G_OBJECT (widget), "toggled", G_CALLBACK (apply_to_topic_changed), win);
 	widget = glade_xml_get_widget (win->xml, "apply to name");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget), win->filter_name);
 	g_signal_connect (G_OBJECT (widget), "toggled", G_CALLBACK (apply_to_name_changed), win);
 
 	widget = glade_xml_get_widget (win->xml, "window 1");
@@ -368,6 +374,7 @@ create_channel_list (session *sess)
 	gtk_widget_show_all (widget);
 
 	g_slist_append (chanlists, win);
+	chanlist_refresh (refresh_button, win);
 }
 
 void
