@@ -1,7 +1,7 @@
 /*
  * irc-network-editor.h - GtkDialog subclass for editing an IrcNetwork
  *
- * Copyright (C) 2004-2005 xchat-gnome team
+ * Copyright (C) 2004-2006 xchat-gnome team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,10 +19,12 @@
  *
  */
 
-#include "util.h"
-#include <gtk/gtk.h>
+#include <config.h>
+#include <glib/gi18n.h>
 #include <string.h>
+#include <gtk/gtk.h>
 #include "irc-network-editor.h"
+#include "util.h"
 
 static GtkDialogClass *parent_class;
 
@@ -219,8 +221,8 @@ irc_network_editor_init (IrcNetworkEditor *dialog)
 	dialog->toplevel = NULL;
 
 	xml = NULL;
-	if (g_file_test ("irc-network-editor.glade", G_FILE_TEST_EXISTS))
-		xml = glade_xml_new ("irc-network-editor.glade", "toplevel", NULL);
+	if (g_file_test ("../../data/irc-network-editor.glade", G_FILE_TEST_EXISTS))
+		xml = glade_xml_new ("../../data/irc-network-editor.glade", "toplevel", NULL);
 	if (!xml)
 		xml = glade_xml_new (XCHATSHAREDIR "/irc-network-editor.glade", "toplevel", NULL);
 	if (!xml)
@@ -231,8 +233,10 @@ irc_network_editor_init (IrcNetworkEditor *dialog)
 
 	GW(autoconnect);
 	GW(use_ssl);
+	GW(allow_invalid);
 	GW(cycle);
 
+	GW(nickserv_password);
 	GW(password);
 	GW(encoding_hbox);
 
@@ -262,12 +266,12 @@ irc_network_editor_init (IrcNetworkEditor *dialog)
 	dialog->autojoin_renderer = gtk_cell_renderer_text_new ();
 
 	gtk_tree_view_set_model (GTK_TREE_VIEW (dialog->servers), GTK_TREE_MODEL (dialog->server_store));
-	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (dialog->servers), 0, "Server", dialog->server_renderer, "text", 0, NULL);
+	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (dialog->servers), 0, _("Server"), dialog->server_renderer, "text", 0, NULL);
 	g_object_set (G_OBJECT (dialog->server_renderer), "editable", TRUE, NULL);
 	dialog->server_column = gtk_tree_view_get_column (GTK_TREE_VIEW (dialog->servers), 0);
 
 	gtk_tree_view_set_model (GTK_TREE_VIEW (dialog->autojoin_channels), GTK_TREE_MODEL (dialog->autojoin_store));
-	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (dialog->autojoin_channels), 0, "Channel", dialog->autojoin_renderer, "text", 0, NULL);
+	gtk_tree_view_insert_column_with_attributes (GTK_TREE_VIEW (dialog->autojoin_channels), 0, _("Channel"), dialog->autojoin_renderer, "text", 0, NULL);
 	g_object_set (G_OBJECT (dialog->autojoin_renderer), "editable", TRUE, NULL);
 	dialog->autojoin_column = gtk_tree_view_get_column (GTK_TREE_VIEW (dialog->autojoin_channels), 0);
 
@@ -279,6 +283,7 @@ irc_network_editor_init (IrcNetworkEditor *dialog)
 	gtk_size_group_add_widget (group, dialog->network_name);
 	gtk_size_group_add_widget (group, dialog->encoding);
 	gtk_size_group_add_widget (group, dialog->password);
+	gtk_size_group_add_widget (group, dialog->nickserv_password);
 	g_object_unref (group);
 
 	enc = (gchar **) encodings;
@@ -378,7 +383,7 @@ irc_network_editor_populate (IrcNetworkEditor *e)
 
 	e->gconf = gconf_client_get_default ();
 
-	title = g_strdup_printf ("%s Network Properties", e->network->name);
+	title = g_strdup_printf (_("%s Network Properties"), e->network->name);
 	gtk_window_set_title (GTK_WINDOW (e), title);
 	g_free (title);
 
@@ -395,6 +400,7 @@ irc_network_editor_populate (IrcNetworkEditor *e)
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (e->autoconnect),      e->network->autoconnect);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (e->use_ssl),          e->network->use_ssl);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (e->allow_invalid),    e->network->allow_invalid);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (e->cycle),            e->network->cycle);
 
 	if (e->network->use_global) {
@@ -415,6 +421,8 @@ irc_network_editor_populate (IrcNetworkEditor *e)
 
 	if (e->network->password)
 		gtk_entry_set_text (GTK_ENTRY (e->password), e->network->password);
+	if (e->network->nickserv_password)
+		gtk_entry_set_text (GTK_ENTRY (e->nickserv_password), e->network->nickserv_password);
 
 	gtk_combo_box_set_active (GTK_COMBO_BOX (e->encoding), e->network->encoding);
 
@@ -452,14 +460,17 @@ apply_changes (IrcNetworkEditor *e)
 	if (net->nick)     g_free (net->nick);
 	if (net->real)     g_free (net->real);
 	if (net->autojoin) g_free (net->autojoin);
+	if (net->nickserv_password) g_free (net->nickserv_password);
 
 	net->name     = g_strdup (gtk_entry_get_text (GTK_ENTRY (e->network_name)));
 	net->password = g_strdup (gtk_entry_get_text (GTK_ENTRY (e->password)));
 	net->nick     = g_strdup (gtk_entry_get_text (GTK_ENTRY (e->nickname)));
 	net->real     = g_strdup (gtk_entry_get_text (GTK_ENTRY (e->realname)));
+	net->nickserv_password = g_strdup (gtk_entry_get_text (GTK_ENTRY (e->nickserv_password)));
 
 	net->autoconnect        = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (e->autoconnect));
 	net->use_ssl            = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (e->use_ssl));
+	net->allow_invalid      = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (e->allow_invalid));
 	net->cycle              = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (e->cycle));
 	net->use_global         = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (e->use_globals));
 	net->encoding           = gtk_combo_box_get_active (GTK_COMBO_BOX (e->encoding));
