@@ -1,7 +1,7 @@
 /*
  * irc-network-editor.h - GtkDialog subclass for editing an IrcNetwork
  *
- * Copyright (C) 2004-2005 xchat-gnome team
+ * Copyright (C) 2004-2006 xchat-gnome team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -51,9 +51,11 @@ struct _IrcNetworkEditor
 
 	GtkWidget *autoconnect;
 	GtkWidget *use_ssl;
+	GtkWidget *allow_invalid;
 	GtkWidget *cycle;
 
 	GtkWidget *password;
+	GtkWidget *nickserv_password;
 	GtkWidget *encoding_hbox;
 	GtkWidget *encoding;
 
