@@ -1,7 +1,7 @@
 /*
  * textentry.c - Widget encapsulating the text entry
  *
- * Copyright (C) 2005 xchat-gnome team
+ * Copyright (C) 2004-2006 xchat-gnome team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -278,67 +278,67 @@ text_entry_populate_popup (GtkEntry *entry, GtkMenu *menu, gpointer data)
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (item), submenu);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);
 
-	item = gtk_image_menu_item_new_with_label ("Black");
+	item = gtk_image_menu_item_new_with_label (_("Black"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), get_color_icon (1, gtk_widget_get_style (item)));
 	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (color_code_activate), (gpointer) 1);
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
-	item = gtk_image_menu_item_new_with_label ("Dark Blue");
+	item = gtk_image_menu_item_new_with_label (_("Dark Blue"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), get_color_icon (2, gtk_widget_get_style (item)));
 	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (color_code_activate), (gpointer) 2);
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
-	item = gtk_image_menu_item_new_with_label ("Dark Green");
+	item = gtk_image_menu_item_new_with_label (_("Dark Green"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), get_color_icon (3, gtk_widget_get_style (item)));
 	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (color_code_activate), (gpointer) 3);
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
-	item = gtk_image_menu_item_new_with_label ("Red");
+	item = gtk_image_menu_item_new_with_label (_("Red"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), get_color_icon (4, gtk_widget_get_style (item)));
 	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (color_code_activate), (gpointer) 4);
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
-	item = gtk_image_menu_item_new_with_label ("Brown");
+	item = gtk_image_menu_item_new_with_label (_("Brown"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), get_color_icon (5, gtk_widget_get_style (item)));
 	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (color_code_activate), (gpointer) 5);
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
-	item = gtk_image_menu_item_new_with_label ("Purple");
+	item = gtk_image_menu_item_new_with_label (_("Purple"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), get_color_icon (6, gtk_widget_get_style (item)));
 	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (color_code_activate), (gpointer) 6);
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
-	item = gtk_image_menu_item_new_with_label ("Orange");
+	item = gtk_image_menu_item_new_with_label (_("Orange"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), get_color_icon (7, gtk_widget_get_style (item)));
 	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (color_code_activate), (gpointer) 7);
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
-	item = gtk_image_menu_item_new_with_label ("Yellow");
+	item = gtk_image_menu_item_new_with_label (_("Yellow"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), get_color_icon (8, gtk_widget_get_style (item)));
 	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (color_code_activate), (gpointer) 8);
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
-	item = gtk_image_menu_item_new_with_label ("Light Green");
+	item = gtk_image_menu_item_new_with_label (_("Light Green"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), get_color_icon (9, gtk_widget_get_style (item)));
 	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (color_code_activate), (gpointer) 9);
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
-	item = gtk_image_menu_item_new_with_label ("Aqua");
+	item = gtk_image_menu_item_new_with_label (_("Aqua"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), get_color_icon (10, gtk_widget_get_style (item)));
 	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (color_code_activate), (gpointer) 10);
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
-	item = gtk_image_menu_item_new_with_label ("Light Blue");
+	item = gtk_image_menu_item_new_with_label (_("Light Blue"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), get_color_icon (11, gtk_widget_get_style (item)));
 	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (color_code_activate), (gpointer) 11);
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
-	item = gtk_image_menu_item_new_with_label ("Blue");
+	item = gtk_image_menu_item_new_with_label (_("Blue"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), get_color_icon (12, gtk_widget_get_style (item)));
 	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (color_code_activate), (gpointer) 12);
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
-	item = gtk_image_menu_item_new_with_label ("Violet");
+	item = gtk_image_menu_item_new_with_label (_("Violet"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), get_color_icon (13, gtk_widget_get_style (item)));
 	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (color_code_activate), (gpointer) 13);
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
-	item = gtk_image_menu_item_new_with_label ("Grey");
+	item = gtk_image_menu_item_new_with_label (_("Grey"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), get_color_icon (14, gtk_widget_get_style (item)));
 	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (color_code_activate), (gpointer) 14);
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
-	item = gtk_image_menu_item_new_with_label ("Light Grey");
+	item = gtk_image_menu_item_new_with_label (_("Light Grey"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), get_color_icon (15, gtk_widget_get_style (item)));
 	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (color_code_activate), (gpointer) 15);
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
-	item = gtk_image_menu_item_new_with_label ("White");
+	item = gtk_image_menu_item_new_with_label (_("White"));
 	gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item), get_color_icon (0, gtk_widget_get_style (item)));
 	g_signal_connect (G_OBJECT (item), "activate", G_CALLBACK (color_code_activate), (gpointer) 0);
 	gtk_menu_shell_append (GTK_MENU_SHELL (submenu), item);
