@@ -1,7 +1,7 @@
 /*
  * userlist.h - the userlist object
  *
- * Copyright (C) 2004-2005 xchat-gnome team
+ * Copyright (C) 2004-2006 xchat-gnome team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,8 @@
  *
  */
 
-#include <gnome.h>
+#include <glib-object.h>
+#include <gtk/gtkliststore.h>
 #include "../common/xchat.h"
 #include "../common/userlist.h"
 
